/***************************************************************************
 *   Copyright (C) 2006 Nicolas Hadacek <hadacek@kde.org>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "synchronous.h"
#include "synchronous.moc"

#include "global.h"
#if QT_VERSION<0x040000
#  include <qwidget.h>
#endif

//------------------------------------------------------------------------------
Synchronous::Synchronous(uint timeout)
: _state(Stopped),
  _timer(NULL)
{
  if (timeout) {
    _timer = new QTimer(this);
    connect(_timer, SIGNAL(timeout()), SLOT(done()));
    _timer->start(timeout, true);
  }
#if QT_VERSION>=0x040000
  _loop = new QEventLoop(this);
#endif
}

#if QT_VERSION<0x040000
void qt_enter_modal(QWidget *widget);
void qt_leave_modal(QWidget *widget);
#endif

bool Synchronous::enterLoop()
{
  Q_ASSERT( _state!=Running );
  if ( _state==Done ) return true;
  _state = Running;
#if QT_VERSION<0x040000
  std::auto_ptr<QWidget> dummy;
  if ( qApp->type()!=QApplication::Tty ) {
    dummy.reset(new QWidget(0, 0, WType_Dialog | WShowModal));
    dummy->setFocusPolicy(QWidget::NoFocus);
    qt_enter_modal(dummy.get());
  }
  QApplication::eventLoop()->enterLoop();
  if ( qApp->type()!=QApplication::Tty ) {
    qt_leave_modal(dummy.get());
  }
#else
  _loop->exec();
#endif
  return (_timer != NULL ? _timer->isActive() : true);
}

void Synchronous::done()
{
  if ( _state==Running ) {
#if QT_VERSION<0x040000
    QApplication::eventLoop()->exitLoop();
#else
    _loop->exit();
#endif
  }
  _state = Done;
}
